/**
 * {{ title }} - Index
 * {{ description }}
 * 
 * Zone: {{ zone_name }}
 * Apps: {{ apps | join(', ') }}
 */

export * from './sdk.gen';
export * from './types.gen';
export * from './client.gen';

// Re-export main client for convenience
export { client as default } from './client.gen'; 